@@ -262,6 +262,9 @@ FcitxIMContext *fcitx_im_context_new(void) {
 static gboolean check_app_name(const gchar *pattern) {
     bool result = FALSE;
     const gchar *prgname = g_get_prgname();
+    if (!prgname) {
+        return FALSE;
+    }
     gchar **p;
     gchar **apps = g_strsplit(pattern, ",", 0);
     for (p = apps; *p != NULL; p++) {
@@ -492,7 +495,12 @@ static void fcitx_im_context_finalize(GObject *obj) {
     g_clear_pointer(&context->preedit_string, g_free);
     g_clear_pointer(&context->surrounding_text, g_free);
     g_clear_pointer(&context->attrlist, pango_attr_list_unref);
-    g_queue_clear_full(&context->gdk_events, (GDestroyNotify)gdk_event_free);
+    /* https://github.com/GNOME/glib/blob/main/glib/gqueue.c#L164
+     * Compatible with glib 2.5.58 < 2.60
+     * g_queue_clear_full(&context->gdk_events,
+     * (GDestroyNotify)gdk_event_free);*/
+    g_queue_foreach(&context->gdk_events, (GFunc)gdk_event_free, NULL);
+    g_queue_clear(&context->gdk_events);
 
     G_OBJECT_CLASS(parent_class)->finalize(obj);
 }
@@ -506,10 +514,11 @@ static void fcitx_im_context_set_client_window(GtkIMContext *context,
     }
     delete fcitxcontext->candidate_window;
     fcitxcontext->candidate_window = nullptr;
-    if (!client_window)
-        return;
-
     g_clear_object(&fcitxcontext->client_window);
+    if (!client_window) {
+        return;
+    }
+
     fcitxcontext->client_window = GDK_WINDOW(g_object_ref(client_window));
 
     _fcitx_im_context_set_capability(fcitxcontext, FALSE);
